@@ -7,7 +7,7 @@ from .listing.generator import ListingGenerator
 from .util import stream_generator
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import asyncpraw
+    import asyncpraw
 
 
 class Inbox(AsyncPRAWBase):
@@ -80,6 +80,23 @@ class Inbox(AsyncPRAWBase):
             self._reddit, API_PATH["comment_replies"], **generator_kwargs
         )
 
+    async def mark_all_read(self):
+        """Mark all messages as read with just one API call.
+
+        Example usage:
+
+        .. code-block:: python
+
+            await reddit.inbox.mark_all_read()
+
+        .. note::
+
+            This method returns after Reddit acknowleges your request, instead of after
+            the request has been fulfilled.
+
+        """
+        await self._reddit.post(API_PATH["read_all_messages"])
+
     async def mark_read(
         self, items: List[Union["asyncpraw.models.Comment", "asyncpraw.models.Message"]]
     ):
