@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Any, Dict, Iterator
 from ..base import AsyncPRAWBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import asyncpraw
+    import asyncpraw
 
 
 class BaseList(AsyncPRAWBase):
