@@ -17,10 +17,10 @@ class ReportableMixin:
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.report("report reason")
 
-            comment = await reddit.comment(id="dxolpyc", lazy=True)
+            comment = await reddit.comment(id="dxolpyc", fetch=False)
             await comment.report("report reason")
 
         """
