@@ -10,7 +10,7 @@ from .base import RedditBase
 from .mixins import FullnameMixin, MessageableMixin
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import asyncpraw
+    import asyncpraw
 
 
 class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase):
@@ -291,6 +291,9 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
         :returns: A ``list`` of :class:`~asyncpraw.models.Subreddit` objects. Return
             ``[]`` if the redditor has no moderated subreddits.
 
+        :raises: ``asyncprawcore.ServerError`` in certain cicumstances. See the note
+            below.
+
         .. note::
 
             The redditor's own user profile subreddit will not be returned, but other
@@ -305,6 +308,30 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
                 print(subreddit.display_name)
                 print(subreddit.title)
 
+        .. note::
+
+            A ``asyncprawcore.ServerError`` exception may be raised if the redditor
+            moderates a large number of subreddits. If that happens, try switching to
+            :ref:`read-only mode <read_only_application>`. For example,
+
+            .. code-block:: python
+
+                reddit.read_only = True
+                redditor = await reddit.redditor("reddit")
+                async for subreddit in redditor.moderated():
+                    print(str(subreddit))
+
+            It is possible that requests made in read-only mode will also raise a
+            ``asyncprawcore.ServerError`` exception.
+
+            When used in read-only mode, this method does not retrieve information about
+            subreddits that require certain special permissions to access, e.g., private
+            subreddits and premium-only subreddits.
+
+        .. seealso::
+
+            :meth:`.User.moderator_subreddits`
+
         """
         return await self._reddit.get(API_PATH["moderated"].format(user=self)) or []
 
