@@ -1,6 +1,7 @@
 """Provide the Submission class."""
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 from urllib.parse import urljoin
+from warnings import warn
 
 from asyncprawcore import Conflict
 
@@ -87,7 +88,7 @@ class SubmissionModeration(ThingModerationMixin):
 
     .. code-block:: python
 
-        submission = await reddit.submission(id="8dmv8z", lazy=True)
+        submission = await reddit.submission(id="8dmv8z", fetch=False)
         await submission.mod.approve()
 
     """
@@ -120,7 +121,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mod.contest_mode(state=True)
 
         """
@@ -148,7 +149,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mod.flair(text="PRAW", css_class="bot")
 
         """
@@ -227,7 +228,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mod.sfw()
 
         .. seealso::
@@ -249,7 +250,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mod.spoiler()
 
         .. seealso::
@@ -273,7 +274,7 @@ class SubmissionModeration(ThingModerationMixin):
         .. note::
 
             When a submission is stickied two or more times, the Reddit API responds
-            with a 409 error that is raises as a ``Conflict`` by asyncprawcore. The
+            with a 409 error that is raised as a ``Conflict`` by asyncprawcore. This
             method suppresses these ``Conflict`` errors.
 
         This submission will replace the second stickied submission if one exists.
@@ -282,7 +283,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mod.sticky()
 
         """
@@ -494,48 +495,6 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         """Return the class's kind."""
         return self._reddit.config.kinds["submission"]
 
-    async def comments(self) -> CommentForest:
-        """Provide an instance of :class:`.CommentForest`.
-
-        This attribute can be used, for example, to obtain a flat list of comments, with
-        any :class:`.MoreComments` removed:
-
-        .. code-block:: python
-
-            comments = await submission.comments()
-            await comments.replace_more(limit=0)
-            comment_list = await comments.list()
-            for comment in comment_list:
-                # do stuff with comment
-                ...
-
-        Sort order and comment limit can be set with the ``comment_sort`` and
-        ``comment_limit`` attributes before comments are fetched, including any call to
-        :meth:`.replace_more`:
-
-        .. code-block:: python
-
-            submission.comment_sort = "new"
-            comments = await submission.comments()
-            comment_list = await comments.list()
-            for comment in comment_list:
-                # do stuff with comment
-                ...
-
-        .. note::
-
-            The appropriate values for ``comment_sort`` include ``confidence``,
-            ``controversial``, ``new``, ``old``, ``q&a``, and ``top``
-
-        See :ref:`extracting_comments` for more on working with a
-        :class:`.CommentForest`.
-
-        """
-        # This assumes _comments is set so that _fetch is called when it's not.
-        if "_comments" not in self.__dict__:
-            await self._fetch()
-        return self._comments
-
     @cachedproperty
     def flair(self) -> SubmissionFlair:
         """Provide an instance of :class:`.SubmissionFlair`.
@@ -563,7 +522,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="8dmv8z", lazy=True)
+            submission = await reddit.submission(id="8dmv8z", fetch=False)
             await submission.mod.approve()
 
         """
@@ -590,7 +549,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         :param reddit: An instance of :class:`~.Reddit`.
         :param id: A reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by :meth:`~asyncpraw.models.Submission.id_from_url`.
+        :param url: A URL supported by :meth:`~.id_from_url`.
 
         Either ``id`` or ``url`` can be provided, but not both.
 
@@ -610,6 +569,40 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         super().__init__(reddit, _data=_data)
 
         self._comments_by_id = {}
+        self.comments = CommentForest(self)
+        """Provide an instance of :class:`.CommentForest`.
+
+        This attribute can be used, for example, to obtain a flat list of comments, with
+        any :class:`.MoreComments` removed:
+
+        .. code-block:: python
+
+            await submission.comments.replace_more(limit=0)
+            comments = submission.comments.list()
+
+        :raises: :py:class:`TypeError` if the submission is not fetched.
+
+        Sort order and comment limit must be set with the ``comment_sort`` and
+        ``comment_limit`` attributes before the submission and its comments are fetched,
+        including any call to :meth:`.replace_more`. The ``fetch`` argument will need to
+        set when initializing the :class:`.Submission` instance:
+
+        .. code-block:: python
+
+            submission = await reddit.submission("8dmv8z", fetch=False)
+            submission.comment_sort = "new"
+            await submission.load()
+            comments = submission.comments.list()
+
+        .. note::
+
+            The appropriate values for ``comment_sort`` include ``confidence``,
+            ``controversial``, ``new``, ``old``, ``q&a``, and ``top``
+
+        See :ref:`extracting_comments` for more on working with a
+        :class:`.CommentForest`.
+
+        """
 
     def __setattr__(self, attribute: str, value: Any):
         """Objectify author, subreddit, and poll data attributes."""
@@ -619,6 +612,17 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
             value = Subreddit(self._reddit, value)
         elif attribute == "poll_data":
             value = PollData(self._reddit, value)
+        elif (
+            attribute == "comment_sort"
+            and hasattr(self, "_fetched")
+            and self._fetched
+            and hasattr(self, "_reddit")
+            and self._reddit.config.warn_comment_sort
+        ):
+            warn(
+                "The comments for this submission have already been fetched, "
+                "so the updated comment_sort will not have any effect"
+            )
         super().__setattr__(attribute, value)
 
     def _chunk(self, other_submissions, chunk_size):
@@ -650,12 +654,11 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
         submission = type(self)(self._reddit, _data=submission_data)
         delattr(submission, "comment_limit")
         delattr(submission, "comment_sort")
-        submission._comments = CommentForest(self)
+        submission.comments = CommentForest(self)
 
         self.__dict__.update(submission.__dict__)
-        self._comments._update(comment_listing.children)
-
         self._fetched = True
+        self.comments._update(comment_listing.children)
 
     async def mark_visited(self):
         """Mark submission as visited.
@@ -666,7 +669,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.mark_visited()
 
         """
@@ -685,7 +688,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n", lazy=True)
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.hide()
 
         .. seealso::
@@ -708,7 +711,7 @@ class Submission(SubmissionListingMixin, UserContentMixin, FullnameMixin, Reddit
 
         .. code-block:: python
 
-            submission = await reddit.submission(id="5or86n")
+            submission = await reddit.submission(id="5or86n", fetch=False)
             await submission.unhide()
 
         .. seealso::
