@@ -40,6 +40,7 @@ from .exceptions import (
     MissingRequiredAttributeException,
     RedditAPIException,
 )
+from .models.util import deprecate_lazy
 from .objector import Objector
 from .util.token_manager import BaseTokenManager
 
@@ -82,7 +83,7 @@ class Reddit:
     """
 
     update_checked = False
-    _ratelimit_regex = re.compile(r"([0-9]{1,2}) (seconds?|minutes?)")
+    _ratelimit_regex = re.compile(r"([0-9]{1,3}) (milliseconds?|seconds?|minutes?)")
 
     @property
     def _next_unique(self) -> int:
@@ -323,6 +324,34 @@ class Reddit:
 
         """
 
+        self.drafts = models.DraftHelper(self, None)
+        """An instance of :class:`.DraftHelper`.
+
+        Provides the interface for working with :class:`.Draft` instances.
+
+        For example, to list the currently authenticated user's drafts:
+
+        .. code-block:: python
+
+            drafts = await reddit.drafts()
+
+        You can also asynchronously iterate through the currently authenticated user's
+        drafts:
+
+        .. code-block:: python
+
+            async for draft in reddit.drafts():
+                # do stuff with draft
+                ...
+
+        To create a draft on r/redditdev run:
+
+        .. code-block:: python
+
+            await reddit.drafts.create(title="title", selftext="selftext", subreddit="redditdev")
+
+        """
+
         self.front = models.Front(self)
         """An instance of :class:`.Front`.
 
@@ -496,6 +525,8 @@ class Reddit:
             self.config.kinds["trophy"]: models.Trophy,
             "Button": models.Button,
             "Collection": models.Collection,
+            "Draft": models.Draft,
+            "DraftList": models.DraftList,
             "Image": models.Image,
             "LabeledMulti": models.Multireddit,
             "Listing": models.Listing,
@@ -509,6 +540,7 @@ class Reddit:
             "Submenu": models.Submenu,
             "TrophyList": models.TrophyList,
             "UserList": models.RedditorList,
+            "UserSubreddit": models.UserSubreddit,
             "button": models.ButtonWidget,
             "calendar": models.Calendar,
             "community-list": models.CommunityList,
@@ -573,35 +605,37 @@ class Reddit:
         self._read_only_core = session(read_only_authorizer)
         self._prepare_common_authorizer(authenticator)
 
+    @deprecate_lazy
     async def comment(
         self,  # pylint: disable=invalid-name
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         url: Optional[str] = None,
-        lazy: bool = False,
+        fetch: bool = True,
+        **kwargs,
     ):
         """Return an instance of :class:`~.Comment`.
 
         :param id: The ID of the comment.
         :param url: A permalink pointing to the comment.
-        :param lazy: If True, object is loaded lazily (default: False).
+        :param fetch: Determines if Async PRAW will fetch the object (default: True).
 
         If you don't need the object fetched right away (e.g., to utilize a class
         method) then you can do:
 
         .. code-block:: python
 
-            comment = await reddit.comment("comment_id", lazy=True)
+            comment = await reddit.comment("comment_id", fetch=False)
             await comment.reply("reply")
 
         .. note::
 
-            If call this with ``lazy=True`` and you need to obtain the comment's
-            replies, you will need to call this without ``lazy=True`` or call
+            If call this with ``fetch=False`` and you need to obtain the comment's
+            replies, you will need to call this without ``fetch=False`` or call
             :meth:`~.Comment.refresh` on the returned :class:`.Comment`.
 
         """
         comment = models.Comment(self, id=id, url=url)
-        if not lazy:
+        if fetch:
             await comment._fetch()
         return comment
 
@@ -747,10 +781,12 @@ class Reddit:
                 if not amount_search:
                     break
                 seconds = int(amount_search.group(1))
-                if "minute" in amount_search.group(2):
+                if amount_search.group(2).startswith("minute"):
                     seconds *= 60
+                elif amount_search.group(2).startswith("millisecond"):
+                    seconds = 0
                 if seconds <= int(self.config.ratelimit_seconds):
-                    sleep_seconds = seconds + min(seconds / 10, 1)
+                    sleep_seconds = seconds + 1
                     return sleep_seconds
         return None
 
@@ -759,6 +795,7 @@ class Reddit:
         path: str,
         data: Optional[Union[Dict[str, Union[str, Any]], bytes, IO, str]] = None,
         json=None,
+        params: Optional[Union[str, Dict[str, str]]] = None,
     ) -> Any:
         """Return parsed objects returned from a DELETE request to ``path``.
 
@@ -768,10 +805,11 @@ class Reddit:
         :param json: JSON-serializable object to send in the body of the request with a
             Content-Type header of application/json (default: None). If ``json`` is
             provided, ``data`` should not be.
+        :param params: The query parameters to add to the request (default: None).
 
         """
         return await self._objectify_request(
-            data=data, json=json, method="DELETE", path=path
+            data=data, json=json, method="DELETE", params=params, path=path
         )
 
     async def patch(
@@ -817,28 +855,29 @@ class Reddit:
         """
         if json is None:
             data = data or {}
-        try:
-            return await self._objectify_request(
-                data=data,
-                files=files,
-                json=json,
-                method="POST",
-                params=params,
-                path=path,
-            )
-        except RedditAPIException as exception:
-            seconds = self._handle_rate_limit(exception=exception)
-            if seconds is not None:
-                logger.debug(f"Rate limit hit, sleeping for {seconds:.2f} seconds")
-                await asyncio.sleep(seconds)
+
+        attempts = 3
+        last_exception = None
+        while attempts > 0:
+            attempts -= 1
+            try:
                 return await self._objectify_request(
                     data=data,
                     files=files,
+                    json=json,
                     method="POST",
                     params=params,
                     path=path,
                 )
-            raise
+            except RedditAPIException as exception:
+                last_exception = exception
+                seconds = self._handle_rate_limit(exception=exception)
+                if seconds is None:
+                    break
+                second_string = "second" if seconds == 1 else "seconds"
+                logger.debug(f"Rate limit hit, sleeping for {seconds} {second_string}")
+                await asyncio.sleep(seconds)
+        raise last_exception
 
     async def put(
         self,
@@ -889,6 +928,7 @@ class Reddit:
 
         :param name: The name of the redditor.
         :param fullname: The fullname of the redditor, starting with ``t2_``.
+        :param fetch: Determines if Async PRAW will fetch the object (default: False).
 
         Either ``name`` or ``fullname`` can be provided, but not both.
 
@@ -954,15 +994,19 @@ class Reddit:
                 [data["reason"], explanation, field]
             ) from exception
 
+    @deprecate_lazy
     async def submission(  # pylint: disable=invalid-name,redefined-builtin
-        self, id: Optional[str] = None, url: Optional[str] = None, lazy=False
+        self,
+        id: Optional[str] = None,
+        url: Optional[str] = None,
+        fetch: bool = True,
+        **kwargs,
     ) -> "asyncpraw.models.Submission":
         """Return an instance of :class:`~.Submission`.
 
         :param id: A Reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by
-            :meth:`~asyncpraw.models.Submission.id_from_url`.`.
-        :param lazy: If True, object is loaded lazily (default: False).
+        :param url: A URL supported by :meth:`~asyncpraw.models.Submission.id_from_url`.
+        :param fetch: Determines if Async PRAW will fetch the object (default: True).
 
         Either ``id`` or ``url`` can be provided, but not both.
 
@@ -971,12 +1015,12 @@ class Reddit:
 
         .. code-block:: python
 
-            submission = await reddit.submission("submission_id", lazy=True)
+            submission = await reddit.submission("submission_id", fetch=False)
             await submission.mod.remove()
 
         """
         submission = models.Submission(self, id=id, url=url)
-        if not lazy:
+        if fetch:
             await submission._fetch()
         return submission
 
