@@ -27,11 +27,10 @@ class TestMore(IntegrationTest):
                 "cu5pbdh",
             ],
         }
-        with self.use_cassette(match_requests_on=["uri", "method", "body"]):
+        with self.use_cassette():
             more = MoreComments(self.reddit, data)
             more.submission = await self.reddit.submission("3hahrw")
-            comments = await more.comments()
-            assert len(comments) == 7
+            assert len((await more.comments())) == 7
 
     async def test_comments__continue_thread_type(self):
         data = {
@@ -41,8 +40,7 @@ class TestMore(IntegrationTest):
             "parent_id": "t1_cu5v5h7",
             "children": [],
         }
-        with self.use_cassette(match_requests_on=["uri", "method", "body"]):
+        with self.use_cassette():
             more = MoreComments(self.reddit, data)
             more.submission = await self.reddit.submission("3hahrw")
-            comments = await more.comments()
-            assert len(comments) == 1
+            assert len((await more.comments())) == 1
