@@ -260,8 +260,12 @@ class TestSubreddit(IntegrationTest):
             await submission.load()
             assert submission.author == pytest.placeholders.username
             assert (
-                submission.selftext
-                == "Text with a gif\n\n[optional caption](https://i.redd.it/s1i7ejqkgdc61.gif)\n\nan image\n\n[optional caption](https://preview.redd.it/95pza2skgdc61.png?width=128&format=png&auto=webp&s=c81d303645d9792afcdb9c47f0a6039708714274)\n\nand a video\n\n[optional caption](https://reddit.com/link/l0vyxc/video/qeg2azskgdc61/player)\n\ninline"
+                submission.selftext == "Text with a gif\n\n[optional"
+                " caption](https://i.redd.it/s1i7ejqkgdc61.gif)\n\nan"
+                " image\n\n[optional"
+                " caption](https://preview.redd.it/95pza2skgdc61.png?width=128&format=png&auto=webp&s=c81d303645d9792afcdb9c47f0a6039708714274)\n\nand"
+                " a video\n\n[optional"
+                " caption](https://reddit.com/link/l0vyxc/video/qeg2azskgdc61/player)\n\ninline"
             )
             assert submission.title == "title"
 
@@ -1118,7 +1122,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.delete(template["id"])
 
     @mock.patch("asyncio.sleep", return_value=None)
@@ -1126,7 +1130,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"],
                 "PRAW updated",
@@ -1157,7 +1161,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"],
                 "PRAW updated",
@@ -1172,7 +1176,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"],
                 "PRAW updated",
@@ -1186,7 +1190,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"],
                 css_class="myCSS",
@@ -1200,7 +1204,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"],
                 text_color="dark",
@@ -1213,7 +1217,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(template["id"], fetch=True)
             newtemplate = list(
                 filter(
@@ -1228,7 +1232,7 @@ class TestSubredditFlairTemplates(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
-            template = await self.async_next(subreddit.flair.templates)
+            template = next(iter(await self.async_list(subreddit.flair.templates)))
             await subreddit.flair.templates.update(
                 template["id"], text_editable=True, fetch=True
             )
@@ -1271,6 +1275,19 @@ class TestSubredditLinkFlairTemplates(IntegrationTest):
             subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
             await subreddit.flair.link_templates.clear()
 
+    async def test_user_selectable(self):
+        self.reddit.read_only = False
+        with self.use_cassette():
+            subreddit = await self.reddit.subreddit(pytest.placeholders.test_subreddit)
+            templates = await self.async_list(
+                subreddit.flair.link_templates.user_selectable()
+            )
+        assert len(templates) >= 2
+
+        for template in templates:
+            assert template["flair_template_id"]
+            assert template["flair_text"]
+
 
 class TestSubredditListings(IntegrationTest):
     async def test_comments(self):
@@ -1831,18 +1848,13 @@ class TestSubredditStreams(IntegrationTest):
 
     @mock.patch("asyncio.sleep", return_value=None)
     async def test_comments__with_skip_existing(self, _):
-        with self.use_cassette("TestSubredditStreams.test_comments__with_pause"):
+        with self.use_cassette():
             subreddit = await self.reddit.subreddit("askreddit")
-            generator = subreddit.stream.comments(skip_existing=True)
-            count = 0
-            try:
-                async for comment in generator:
-                    count += 1
-            except TypeError:
-                pass
-            # This test uses the same cassette as test_comments which shows
-            # that there are at least 100 comments in the stream.
-            assert count < 102
+            generator = subreddit.stream.comments(skip_existing=True, pause_after=-1)
+            comment = await self.async_next(generator)
+            assert comment is None
+            comment = await self.async_next(generator)
+            assert isinstance(comment, Comment)
 
     @mock.patch("asyncio.sleep", return_value=None)
     async def test_submissions(self, _):
