@@ -34,9 +34,7 @@ class TestWikiPage(UnitTest):
 
     def test_repr(self):
         page = WikiPage(self.reddit, subreddit=Subreddit(self.reddit, "a"), name="x")
-        assert repr(page) == (
-            "WikiPage(subreddit=Subreddit(display_name='a'), name='x')"
-        )
+        assert repr(page) == "WikiPage(subreddit=Subreddit(display_name='a'), name='x')"
 
     def test_str(self):
         page = WikiPage(self.reddit, subreddit=Subreddit(self.reddit, "a"), name="x")
