@@ -64,7 +64,8 @@ class TestReddit(UnitTest):
             )
         assert (
             str(excinfo.value)
-            == "``refresh_token`` setting cannot be provided when providing ``token_manager``"
+            == "``refresh_token`` setting cannot be provided when providing"
+            " ``token_manager``"
         )
 
     async def test_context_manager(self):
@@ -90,13 +91,15 @@ class TestReddit(UnitTest):
             Reddit(timeout="test", **self.REQUIRED_DUMMY_SETTINGS)
         assert (
             excinfo.value.args[0]
-            == "An incorrect config type was given for option timeout. The expected type is int, but the given value is test."
+            == "An incorrect config type was given for option timeout. The expected"
+            " type is int, but the given value is test."
         )
         with pytest.raises(ValueError) as excinfo:
             Reddit(ratelimit_seconds="test", **self.REQUIRED_DUMMY_SETTINGS)
         assert (
             excinfo.value.args[0]
-            == "An incorrect config type was given for option ratelimit_seconds. The expected type is int, but the given value is test."
+            == "An incorrect config type was given for option ratelimit_seconds. The"
+            " expected type is int, but the given value is test."
         )
 
     def test_info__not_list(self):
@@ -126,7 +129,81 @@ class TestReddit(UnitTest):
                     "errors": [
                         [
                             "RATELIMIT",
-                            "You are doing that too much. Try again in 5 seconds.",
+                            "Some unexpected error message",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__invalid_rate_limit_message(self, mock_sleep, _):
+        with pytest.raises(RedditAPIException) as exception:
+            await self.reddit.post("test")
+        assert exception.value.message == "Some unexpected error message"
+        mock_sleep.assert_not_called()
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 6 seconds.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__over_threshold__seconds(self, mock_sleep, _):
+        with pytest.raises(RedditAPIException) as exception:
+            await self.reddit.post("test")
+        assert (
+            exception.value.message
+            == "You are doing that too much. Try again in 6 seconds."
+        )
+        mock_sleep.assert_not_called()
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 1 minute.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__over_threshold__minutes(self, __, _):
+        with pytest.raises(RedditAPIException) as exception:
+            await self.reddit.post("test")
+        assert (
+            exception.value.message
+            == "You are doing that too much. Try again in 1 minute."
+        )
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 2 milliseconds.",
                             "ratelimit",
                         ]
                     ]
@@ -137,29 +214,7 @@ class TestReddit(UnitTest):
                     "errors": [
                         [
                             "RATELIMIT",
-                            "You are doing that too much. Try again in 5 seconds.",
-                            "ratelimit",
-                        ]
-                    ]
-                }
-            },
-            {
-                "json": {
-                    "errors": [
-                        [
-                            "RATELIMIT",
-                            "You are doing that too much. Try again in 10 minutes.",
-                            "ratelimit",
-                        ]
-                    ]
-                }
-            },
-            {
-                "json": {
-                    "errors": [
-                        [
-                            "RATELIMIT",
-                            "APRIL FOOLS FROM REDDIT, TRY AGAIN",
+                            "You are doing that too much. Try again in 1 millisecond.",
                             "ratelimit",
                         ]
                     ]
@@ -169,23 +224,104 @@ class TestReddit(UnitTest):
         ],
     )
     @mock.patch("asyncio.sleep", return_value=None)
-    async def test_post_ratelimit(self, __, _):
-        with pytest.raises(RedditAPIException) as exc:
+    async def test_post_ratelimit__under_threshold__milliseconds(self, mock_sleep, _):
+        await self.reddit.post("test")
+        mock_sleep.assert_has_calls([mock.call(1), mock.call(1)])
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 1 minute.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+            {},
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__under_threshold__minutes(self, mock_sleep, _):
+        self.reddit.config.ratelimit_seconds = 60
+        await self.reddit.post("test")
+        mock_sleep.assert_has_calls([mock.call(61)])
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 5 seconds.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+            {},
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__under_threshold__seconds(self, mock_sleep, _):
+        await self.reddit.post("test")
+        mock_sleep.assert_has_calls([mock.call(6)])
+
+    @mock.patch(
+        "asyncpraw.Reddit.request",
+        side_effect=[
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 5 seconds.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 3 seconds.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+            {
+                "json": {
+                    "errors": [
+                        [
+                            "RATELIMIT",
+                            "You are doing that too much. Try again in 1 second.",
+                            "ratelimit",
+                        ]
+                    ]
+                }
+            },
+        ],
+    )
+    @mock.patch("asyncio.sleep", return_value=None)
+    async def test_post_ratelimit__under_threshold__seconds_failure(
+        self, mock_sleep, _
+    ):
+        with pytest.raises(RedditAPIException) as exception:
             await self.reddit.post("test")
         assert (
-            exc.value.message == "You are doing that too much. Try again in 5 seconds."
+            exception.value.message
+            == "You are doing that too much. Try again in 1 second."
         )
-        with pytest.raises(RedditAPIException) as exc2:
-            await self.reddit.post("test")
-        assert (
-            exc2.value.message
-            == "You are doing that too much. Try again in 10 minutes."
-        )
-        with pytest.raises(RedditAPIException) as exc3:
-            await self.reddit.post("test")
-        assert exc3.value.message == "APRIL FOOLS FROM REDDIT, TRY AGAIN"
-        response = await self.reddit.post("test")
-        assert response == {}
+        mock_sleep.assert_has_calls([mock.call(6), mock.call(4), mock.call(2)])
 
     async def test_read_only__with_authenticated_core(self):
         async with Reddit(
@@ -331,7 +467,7 @@ class TestReddit(UnitTest):
         )
 
     async def test_submission(self):
-        submission = await self.reddit.submission("2gmzqe", lazy=True)
+        submission = await self.reddit.submission("2gmzqe", fetch=False)
         assert submission.id == "2gmzqe"
 
     async def test_subreddit(self):
